@@ -355,10 +355,8 @@ class RESTAPI :
             for style in participant['perks']['styles'] :
                 for selection in style['selections'] :
                     runes.append(selection['perk'])
-            puuid = participant['puuid']
-            RIOT_KEY = 'RGAPI-ef3247df-953a-4361-80f7-f3f2c255b5d0'
-            summoner = RiotApi(RIOT_KEY, REGIONS['north_america']).get_summoner_by_puuid(puuid)
-            self.post_summoner(summoner)
+            puuid = participant['puuid']            
+                
             body = {
                 "matchid" : "{matchId}".format(matchId=match['metadata']['matchId']),
                 "summonerid" : "{summonerId}".format(summonerId=participant['summonerId']),
@@ -419,6 +417,21 @@ class RESTAPI :
                 "truedamagedealttochampions" : int(participant['trueDamageDealtToChampions']),
                 "win" : participant['win']
             }
+
+            RIOT_KEY = 'RGAPI-ef3247df-953a-4361-80f7-f3f2c255b5d0'
+            r_api = RiotApi(RIOT_KEY, REGIONS['north_america'])
+            summoner = r_api.get_summoner_by_puuid(puuid)
+            league = self.get_league_by_summonerid(summoner['id'])
+            if len(league) == [] :
+                api_url=URL['leagues'].format(url='/')
+                league = r_api.get_league_by_summoner_id(summoner['id'])
+                self.post_league(league)
+
+            championMastery = self.get_championmastery_by_championid_and_summonerid(participant['championId'], summoner['id'])
+            if len(championMastery) == [] :
+                api_url=URL['championmasteries'].format(url='/')
+                championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(summoner['id'], participant['championId'])
+                self.post_championMastery(championMastery)
         
             response = self.get_matchparticipant_by_matchid_and_puuid(match['metadata']['matchId'], puuid)
             if (len(response) == 0) :
@@ -427,6 +440,7 @@ class RESTAPI :
             else :
                 api_url=URL['matchparticipants'].format(url='/'+str(response[0]['id']))
                 self.request_update(api_url, body)
+            
         return True
 
     def post_league(self, leagues) :
